@@ -547,7 +547,8 @@ DECLINLINE(UINT) vboxWddmCalcBitsPerPixel(D3DDDIFORMAT enmFormat)
         case D3DDDIFMT_A2R10G10B10:
             return 32;
         case D3DDDIFMT_A16B16G16R16:
-        case D3DDDIFMT_A16B16G16R16F:
+// Floating-point formats are not implemented in Chromium.
+//        case D3DDDIFMT_A16B16G16R16F:
             return 64;
         case D3DDDIFMT_A8P8:
             return 16;
@@ -597,6 +598,8 @@ DECLINLINE(UINT) vboxWddmCalcBitsPerPixel(D3DDDIFORMAT enmFormat)
             return 32;
         case D3DDDIFMT_R16F:
             return 16;
+        case D3DDDIFMT_YUY2: /* 4 bytes per 2 pixels. */
+            return 16;
         default:
             AssertBreakpoint();
             return 0;
