@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2010 Oracle Corporation
+ * Copyright (C) 2010-2012 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -63,13 +63,11 @@ static RTLISTANCHOR g_rtVfsChainElementProviderList;
  * Initializes the globals via RTOnce.
  *
  * @returns IPRT status code
- * @param   pvUser1             Unused, ignored.
- * @param   pvUser2             Unused, ignored.
+ * @param   pvUser              Unused, ignored.
  */
-static DECLCALLBACK(int) rtVfsChainElementRegisterInit(void *pvUser1, void *pvUser2)
+static DECLCALLBACK(int) rtVfsChainElementRegisterInit(void *pvUser)
 {
-    NOREF(pvUser1);
-    NOREF(pvUser2);
+    NOREF(pvUser);
     return RTCritSectInit(&g_rtVfsChainElementCritSect);
 }
 
@@ -97,7 +95,7 @@ RTDECL(int) RTVfsChainElementRegisterProvider(PRTVFSCHAINELEMENTREG pRegRec, boo
      */
     if (!fFromCtor)
     {
-        rc = RTOnce(&g_rtVfsChainElementInitOnce, rtVfsChainElementRegisterInit, NULL, NULL);
+        rc = RTOnce(&g_rtVfsChainElementInitOnce, rtVfsChainElementRegisterInit, NULL);
         if (RT_FAILURE(rc))
             return rc;
         rc = RTCritSectEnter(&g_rtVfsChainElementCritSect);
@@ -614,11 +612,12 @@ RTDECL(int) RTVfsChainOpenFile(const char *pszSpec, uint64_t fOpen, PRTVFSFILE p
 
 RTDECL(int) RTVfsChainOpenIoStream(const char *pszSpec, uint64_t fOpen, PRTVFSIOSTREAM phVfsIos, const char **ppszError)
 {
+    if (ppszError)
+        *ppszError = NULL;
+
     AssertPtrReturn(pszSpec, VERR_INVALID_POINTER);
     AssertReturn(*pszSpec != '\0', VERR_INVALID_PARAMETER);
     AssertPtrReturn(phVfsIos, VERR_INVALID_POINTER);
-    if (ppszError)
-        *ppszError = NULL;
 
     /*
      * If it's not a VFS chain spec, treat it as a file.
